@@ -55,6 +55,18 @@ class DescribeAvailableZonesRequest(RpcRequest):
 	def set_InstanceChargeType(self,InstanceChargeType):
 		self.add_query_param('InstanceChargeType',InstanceChargeType)
 
+	def get_DispenseMode(self):
+		return self.get_query_params().get('DispenseMode')
+
+	def set_DispenseMode(self,DispenseMode):
+		self.add_query_param('DispenseMode',DispenseMode)
+
+	def get_CommodityCode(self):
+		return self.get_query_params().get('CommodityCode')
+
+	def set_CommodityCode(self,CommodityCode):
+		self.add_query_param('CommodityCode',CommodityCode)
+
 	def get_ZoneId(self):
 		return self.get_query_params().get('ZoneId')
 
