@@ -67,6 +67,12 @@ class DescribeCrossRegionBackupsRequest(RpcRequest):
 	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
 		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
 
+	def get_BackupId(self):
+		return self.get_query_params().get('BackupId')
+
+	def set_BackupId(self,BackupId):
+		self.add_query_param('BackupId',BackupId)
+
 	def get_EndTime(self):
 		return self.get_query_params().get('EndTime')
 
